/*
 * Software License Agreement (BSD License)
 *
 * Copyright (c) 2018 Oliver Mayer, Akademie der Bildenden Kuenste Nuernberg. 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

/*****************************************************************************  
 * Draw custom shapes. Load a shape from an SVG file (Scalable Vector Graphics)
 * or create shapes manually (randomly here)
 *****************************************************************************/


PShape starShape;   // shape object to contain the loaded star
PShape randomShape; // shape object to contain the manually created random shape

void setup() {
  size(500, 500);
  starShape = loadShape("star.svg"); // load vector graphics file
  
  shapeMode(CENTER); // specify shapes by center, width and height
  
  //blendMode(ADD); // change blend mode to add colors
}

void draw() {
  background(0);
  
  // paint star shape in the window's center
  shape(starShape, width/2, height/2, 300, 330);
  
  // create and draw a random shape
  randomShape = createRandomShape(10);
  shape(randomShape, width/2, height/2, 300, 300);
  
  delay(500);
}



PShape createRandomShape(int numVertices) {
  
  PShape s = createShape();   // create shape object
  s.beginShape();             // start adding vertices that are used to define the shape's outline
  //s.beginShape(TRIANGLES);  // alternatively, start adding vertices that are used to define separate triangles
  s.fill(0, 0, 255);          // set the shape's fill color to blue
  s.stroke(0, 255, 0);        // set the shape's stroke color to green
  
  // add random vertices to the shape in the range (x=10, y=10) to (x=width-10, y=height-10)
  // (in fact, the range does not matter here, because the shape is scaled when drawn)
  for (int i = 0; i < numVertices; i++) {
    s.vertex(random(10, width-10), random(10, height-10));  
  }
  
  s.endShape(CLOSE);   // finish and close the shape
  
  return s;
}
